# astropic
Code to modify the images using different redshifts and distances.
May be buggy, submit bugs in Github Issues.
To run your code, install the repository:
WARNING: poetry and poetry-core are needed to build the package
`pip install astropic`
Then you are ready to run the main code.
To use the module in your code, do `from astropic.main import convert` and then run the `convert('info')`
There is also a bonus script fits2png.py, which modifies .fits files into .png files
